Make a variable name better.
author |
Steve Losh <steve@stevelosh.com> |
date |
Fri, 28 Aug 2009 21:21:29 -0400 |
parents |
40775a8b4167
|
children |
ee7035b4344d
|
branches/tags |
(none) |
files |
t.py |
Changes
--- a/t.py Fri Aug 28 21:20:55 2009 -0400
+++ b/t.py Fri Aug 28 21:21:29 2009 -0400
@@ -24,13 +24,13 @@
self.prefix = prefix
-def _hash(s):
- """Return a hash of the given string for use as an id.
+def _hash(text):
+ """Return a hash of the given text for use as an id.
Currently SHA1 hashing is used. It should be plenty for our purposes.
"""
- return hashlib.sha1(s).hexdigest()
+ return hashlib.sha1(text).hexdigest()
def _task_from_taskline(taskline):
"""Parse a taskline (from a task file) and return a task.